class About:
    def __init__(self) -> None:
        print("DeepEdge has emerged as world’s leading full-stack EdgeAI company, providing a broad range of platforms and services, enabling companies to rapidl build and deploy products with EdgeAI capabilities.  ")
        print("contact: projects@deepedge.ai")
